<?php
namespace Landingi\Wordpress\Plugin\LandingiPlugin\Controller;

use Landingi\Wordpress\Plugin\Framework\Controller\PostController;
use Landingi\Wordpress\Plugin\Framework\Http\Request;
use Landingi\Wordpress\Plugin\Framework\Kernel\ConfigCollection;
use Landingi\Wordpress\Plugin\Framework\Util\TwigService;
use Landingi\Wordpress\Plugin\LandingiPlugin\Model\Landing;
use Landingi\Wordpress\Plugin\LandingiPlugin\Service\LandendApiClientService;

class LandingPostController extends PostController
{
    private $landendApiClientService;

    public function __construct(
        TwigService $twigService,
        Request $request,
        ConfigCollection $configCollection,
        LandendApiClientService $landendApiClientService
    ) {
        parent::__construct($twigService, $request, $configCollection);
        $this->landendApiClientService = $landendApiClientService;
    }

    public function action($customPost = null)
    {
        if ($customPost == null) {
            $object = get_queried_object();
        } else {
            $object = $customPost;
        }

        $landingData = json_decode((string)$object->post_content, true);

        $landing = new Landing(
            $landingData['id'],
            $landingData['name'],
            $landingData['hash'],
            $landingData['slug']
        );

        $landing->setTestId($this->request->getCookie('tid'));
        $apiResponse = $this->landendApiClientService->getLandingFromApi($landing, $this->request->getGetParameter('hash'));

        if (in_array($apiResponse['status_code'], [301, 302], true) && !empty($apiResponse['redirect'])) {
            return $this->response(
                'Redirect',
                $apiResponse['status_code'],
                [
                    'Location' => $this->removeInternalQueryParameters($apiResponse['redirect'])
                ]
            );
        }

        $landing->setContent($apiResponse['content']);
        $landing->setTestId($apiResponse['tid']);
        $this->setCookie('tid', $landing->getTestId());
        $this->response(
            $this->modifyButtonSubmissionEndpoints(
                $this->modifyFormAndRedirectInputEndpoints($landing, $object),
                $landing
            )
        );
    }

    private function modifyFormAndRedirectInputEndpoints(Landing $landing, $object)
    {
        return preg_replace(
            '/(<input type="hidden" name="_redirect" value)="">/',
            sprintf(
                '$1="%s/%s">',
                get_option('siteurl'),
                $object->post_name
            ),
            preg_replace(
                '/ action="\/([\s\S]*?)"/',
                sprintf(
                    ' action="%s/${1}?export_hash=%s&tid=%s"',
                    $this->getConfig('landingi_export_url'),
                    $landing->getHash(),
                    $landing->getTestId()
                ),
                $landing->getContent()
            )
        );
    }

    private function modifyButtonSubmissionEndpoints($content, Landing $landing)
    {
        return preg_replace(
            '/ href="(?:\/[^\/]+)?(\/button\/[a-zA-z0-9]{32})"/',
            sprintf(
                ' href="%s${1}?export_hash=%s&tid=%s"',
                $this->getConfig('landingi_export_url'),
                $landing->getHash(),
                $landing->getTestId()
            ),
            preg_replace(
                '/ href="(?:\/[^\/]+)?(\/button\/[a-zA-z0-9]{32})\?lightbox=([a-z0-9]{8}(?:-[a-z0-9]{4}){3}-[a-z0-9]{12})"/',
                sprintf(
                    ' href="%s${1}?export_hash=%s&tid=%s&lightbox=${2}"',
                    $this->getConfig('landingi_export_url'),
                    $landing->getHash(),
                    $landing->getTestId()
                ),
                $content
            )
        );
    }

    private function removeInternalQueryParameters($url)
    {
        $parsedUrl = parse_url($url);
        $queryArray = [];

        if (!empty($parsedUrl['query'])) {
            parse_str($parsedUrl['query'], $queryArray);
        }

        $queryArray = array_merge($queryArray, $_REQUEST);
        unset($queryArray['tid'], $queryArray['export_hash']);
        $queryString = http_build_query($queryArray);

        $scheme = !empty($parsedUrl['scheme']) ? "{$parsedUrl['scheme']}://" : '';
        $host = !empty($parsedUrl['host']) ? $parsedUrl['host'] : '';
        $path = !empty($parsedUrl['path']) ? $parsedUrl['path'] : '';
        $query = !empty($queryString) ? "?$queryString" : '';

        return "{$scheme}{$host}{$path}{$query}";
    }
}
