<?php
namespace Landingi\Wordpress\Plugin\LandingiPlugin\Service;

use GuzzleHttp\Client;
use Landingi\Wordpress\Plugin\LandingiPlugin\Model\Landing;

class LandendApiClientService
{
    private $guzzle;
    private $landingListPath = '/api/render';

    public function __construct($url)
    {
        $this->guzzle = $this->createClient($url);
    }

    private function createClient($url)
    {
        return new Client([
            'base_url' => $url,
            'defaults' => [
                'verify' => false
            ]
        ]);
    }

    private function get($path, $params)
    {
        return $this->guzzle->get($path, [
            'query' => $params
        ]);
    }

    public function getLandingFromApi(Landing $landing, $conversionHash = null)
    {
        $data = [
            'export_hash' => $landing->getHash(),
            'tid' => $landing->getTestId()
        ];

        if ($conversionHash) {
            $data['conversion_hash'] = $conversionHash;
        }

        /** @var \GuzzleHttp\Message\ResponseInterface $request */
        $request = $this->get($this->landingListPath, $data);

        return array_merge(
            ['status_code' => $request->getStatusCode()],
            json_decode($request->getBody()->getContents(), true)
        );
    }
}
